@@ -32,7 +32,7 @@ THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR I
 
 import sys
 
-from .func import trigger
+from .func import command, trigger
 from .gears import ClosedGearFunction, GearFunction, PartialGearFunction
 from .reader import (
     CommandReader,
@@ -46,6 +46,7 @@ from .reader import (
 from .sugar import FailurePolicy, KeyType, LogLevel, ReaderType, TriggerMode
 
 __all__ = [
+    "command",
     "trigger",
     "ClosedGearFunction",
     "GearFunction",
@@ -89,7 +90,7 @@ except ModuleNotFoundError:
 
 try:
     # This will fail if redis package is not installed
-    from .command import cmd
+    from .runtime_client import cmd
 
     __all__ += ["cmd"]
 except ModuleNotFoundError:
@@ -128,6 +129,7 @@ except ModuleNotFoundError:
 # or not (e.g. dev or client)
 if "redisgears" in sys.modules:
     # Server Gears runtime environment
+    GEARS_RUNTIME = True
     # Import the default functions and classes
     # pyright: reportMissingImports=false
     from __main__ import GB as GB
@@ -138,8 +140,10 @@ if "redisgears" in sys.modules:
     from redisgears import executeCommand as execute
     from redisgears import getMyHashTag as hashtag
     from redisgears import log as log
+
 else:
     # Dev or Client environment
+    GEARS_RUNTIME = False
     # Import placeholder functions and
     from .runtime import (
         GB,
@@ -161,4 +165,5 @@ __all__ += [
     "gearsConfigGet",
     "hashtag",
     "log",
+    "GEARS_RUNTIME",
 ]
