@@ -33,14 +33,12 @@ THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR I
 """
 
 import ast
-import sys
 from typing import Any, Dict, Generic, Iterable, List, Optional, TypeVar, Union
 
 import attr
 import cloudpickle
 import wrapt
 
-import redgrease.gears
 from redgrease.utils import (
     REnum,
     bool_ok,
@@ -57,7 +55,7 @@ from redgrease.utils import (
 T = TypeVar("T")
 
 
-@attr.s(frozen=True, auto_attribs=True)
+@attr.s(frozen=True, auto_attribs=True, repr=False)
 class ExecID:
     """Execution ID
 
@@ -72,18 +70,19 @@ class ExecID:
     shard_id: str = "0000000000000000000000000000000000000000"
     sequence: int = 0
 
+    def __repr__(self) -> str:
+        class_name = self.__class__.__name__
+        if self.shard_id == "0000000000000000000000000000000000000000":
+            return f"{class_name}(sequence={self.sequence})"
+        else:
+            return f"""{class_name}("{self.shard_id}", {self.sequence})"""
+
     def __str__(self):
         return f"{self.shard_id}-{self.sequence}"
 
     def __bytes__(self):
         return str(self).encode()
 
-    def __repr__(self):
-        class_name = self.__class__.__name__
-        return (
-            f"{class_name}(" f"shard_id={self.shard_id}," f"sequence={self.sequence})"
-        )
-
     @staticmethod
     def parse(value: Union[str, bytes]) -> "ExecID":
         """Parses a string or bytes representation into a `redgrease.data.ExecID`
@@ -208,7 +207,7 @@ class ExecutionResult(wrapt.ObjectProxy, Generic[T]):
         return self.value(*args, **kwds)
 
 
-def parse_execute_response(response, pickled=False) -> ExecutionResult:
+def parse_execute_response(response) -> ExecutionResult:
     """Parses raw responses from `pyexecute`, `getresults` and `getresultsblocking`
     into a `redgrease.data.ExecuteResponse` object.
 
@@ -222,10 +221,6 @@ def parse_execute_response(response, pickled=False) -> ExecutionResult:
             (e.g. in the absence of a closing `run()` operation) or an excecution ID
             (e.g. for non-blocking executions).
 
-        pickled (bool, optional):
-            Indicates if the response is pickled and need to be unpickled.
-            Defaults to False.
-
     Returns:
         ExecutionResult[T]:
             A parsed execution response
@@ -244,8 +239,10 @@ def parse_execute_response(response, pickled=False) -> ExecutionResult:
 
         result, errors = response
         if isinstance(result, list):
-            if pickled:
+            try:
                 result = [cloudpickle.loads(value) for value in result]
+            except (TypeError, cloudpickle.pickle.UnpicklingError):
+                pass
             if len(result) == 1:
                 result = result[0]
         return ExecutionResult(result, errors=errors)
@@ -257,7 +254,7 @@ def parse_execute_response(response, pickled=False) -> ExecutionResult:
         return ExecutionResult(response)
 
 
-def parse_trigger_response(response, pickled=False) -> ExecutionResult:
+def parse_trigger_response(response) -> ExecutionResult:
     """Parses raw responses from `trigger` into a `redgrease.data.ExecuteResponse`
     object.
 
@@ -275,8 +272,10 @@ def parse_trigger_response(response, pickled=False) -> ExecutionResult:
         ExecutionResult[T]:
             A parsed execution response
     """
-    if pickled:
+    try:
         response = [cloudpickle.loads(value) for value in response]
+    except (TypeError, cloudpickle.pickle.UnpicklingError):
+        pass
 
     if len(response) == 1:
         response = response[0]
@@ -437,7 +436,7 @@ class Registration(RedisObject):
     )
     """Registration Data, see `RegData`."""
 
-    PD: Dict[Any, Any] = attr.ib(converter=parse_PD)
+    PD: Dict[Any, Any] = attr.ib(converter=parse_PD, repr=False)
     """Private data"""
 
 
@@ -569,7 +568,7 @@ class ClusterInfo(RedisObject):
                 A ClusterInfo object or None (if not in cluster mode).s
         """
 
-        if not res or res == b"no cluster mode":
+        if not res or safe_str(res) == "no cluster mode":
             return None
 
         cluster_info = ClusterInfo(
@@ -628,75 +627,3 @@ class PyRequirementInfo(RedisObject):
         else [safe_str(wheel) for wheel in wheels]
     )
     """A List of Wheels required by the requirement."""
-
-
-def deseralize_gear_function(
-    serialized_gear: str, python_version: str
-) -> redgrease.gears.GearFunction:
-    """Safely deserializes (unpickles) a serialized GearFunction.
-
-    This function is only executed on the Gear server.
-
-    It handles and appropriately reports errors due to mismatch between
-    client and server Python versions.
-
-    Args:
-        serialized_gear (str):
-            The serialized (cloudpickled) GearFunction.
-
-        python_version (str):
-            The python version of the client.
-
-    Raises:
-        SystemError:
-            If the Python versions of the client and server mismatch.
-
-    Returns:
-        redgrease.gears.GearFunction:
-            The Gear function, as created on at the client.
-    """
-    try:
-        return cloudpickle.loads(serialized_gear)
-    except Exception as err:
-        import sys
-
-        def pystr(pyver):
-            return "Python %s.%s" % pyver
-
-        runtime_python_version = sys.version_info[:2]
-        function_python_version = ast.literal_eval(str(python_version))[:2]
-        if runtime_python_version != function_python_version:
-            raise SystemError(
-                "Client / server Python version mismatch."
-                f"{pystr(runtime_python_version)} runtime unable to execute "
-                f"Gears functions created in {function_python_version}. "
-            ) from err
-        raise
-
-
-def seralize_gear_function(gear_function: redgrease.gears.GearFunction) -> str:
-    """Serializes a GearFunction into a wrapper code-string that can be sent to the
-    Gear server to execute.
-
-    Args:
-        gear_function (redgrease.gears.ClosedGearFunction):
-            GearFunction to serialize.
-
-    Returns:
-        str:
-            Code string that will execute the GearFunction on the server.
-    """
-
-    # The Gear function is serialized with 'cloudpickle' and embedded in a
-    # code string that will de-serialize it back and then 'construct' the actual
-    # Gear function and run it.
-
-    return f"""
-import redgrease.data
-import redgrease.runtime
-gear_function = redgrease.data.deseralize_gear_function(
-    {cloudpickle.dumps(gear_function, protocol=4)},
-    python_version={tuple(sys.version_info)},
-)
-redgrease.runtime.run(gear_function, GearsBuilder)
-"""
