@@ -25,9 +25,11 @@ THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR I
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
-
 from typing import Any, Dict, Generic, Hashable, Iterable, Optional, Type, TypeVar
 
+import redgrease
+import redgrease.data
+import redgrease.exceptions
 import redgrease.sugar as sugar
 import redgrease.typing as optype
 
@@ -351,9 +353,11 @@ class Register(Operation):
                 A closed Gear event function that is ready to be regisetered on a
                 Gears cluster.
         """
-        return function.register(
+        import cloudpickle
+
+        return function.map(lambda x: cloudpickle.dumps(x, protocol=4)).register(
             self.prefix,
-            self.convertToStr,
+            False,
             self.collect,
             mode=self.mode,
             onRegistered=self.onRegistered,
@@ -1342,6 +1346,7 @@ class ClosedGearFunction(GearFunction[T]):
         gears_server,
         unblocking: bool = False,
         requirements: Iterable[str] = None,
+        replace: bool = None,
         **kwargs,
     ):
         """Execute the function on a Redis Gear server / cluster.
@@ -1370,9 +1375,33 @@ class ClosedGearFunction(GearFunction[T]):
 
             gears_server = Gears(gears_server)
 
-        return gears_server.pyexecute(
-            self, unblocking=unblocking, requirements=requirements, **kwargs
-        )
+        try:
+            return gears_server.pyexecute(
+                self, unblocking=unblocking, requirements=requirements, **kwargs
+            )
+        except redgrease.exceptions.DuplicateTriggerError:
+            # If we get an error because the trigger already is registered,
+            # then we check the 'replace' argument for what to do:
+            # - `replace is None` : Re-raise the error
+            # - `replace is False` : Ignore the error
+            # - `replace is True` : Unregister the previous and re-register the new
+            if replace is None or "trigger" not in self.operation.kwargs:
+                raise
+
+            if replace is False:
+                return gears_server._trigger_proxy(self.operation.kwargs["trigger"])
+
+            # Find and replace the registered trigger.
+            trigger = self.operation.kwargs["trigger"]
+            regs = gears_server.dumpregistrations(trigger=trigger)
+            if len(regs) != 1:
+                raise
+            gears_server.unregister(regs[0].id)
+
+            # Try registering again
+            return gears_server.pyexecute(
+                self, unblocking=unblocking, requirements=requirements, **kwargs
+            )
 
 
 class PartialGearFunction(GearFunction[optype.InputRecord]):
@@ -1448,6 +1477,9 @@ class PartialGearFunction(GearFunction[optype.InputRecord]):
             requirements=requirements,
         )
 
+        if redgrease.GEARS_RUNTIME:
+            return redgrease.runtime.run(gear_fun, redgrease.GearsBuilder)
+
         if on:
             return gear_fun.on(on)
 
@@ -1638,6 +1670,8 @@ class PartialGearFunction(GearFunction[optype.InputRecord]):
         if trigger is not None:
             kwargs["trigger"] = trigger
 
+        replace = kwargs.pop("replace", None)
+
         gear_fun = ClosedGearFunction["optype.InputRecord"](
             Register(
                 prefix=prefix,
@@ -1649,8 +1683,11 @@ class PartialGearFunction(GearFunction[optype.InputRecord]):
             requirements=requirements,
         )
 
+        if redgrease.GEARS_RUNTIME:
+            return redgrease.runtime.run(gear_fun, redgrease.GearsBuilder)
+
         if on:
-            return gear_fun.on(on)
+            return gear_fun.on(on, replace=replace)
 
         return gear_fun
 
